@@ -4,7 +4,7 @@
  * GChemPaint library
  * about.cc 
  *
- * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,12 +26,12 @@
 #include "about.h"
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <string.h>
+#include <cstring>
 
 void on_about (GtkWidget* widget, void* data)
 {
-	char * authors[] = {"Jean Bréfort", NULL};
-	char * artists[] = {"Nestor Diaz", NULL};
+	char * authors[] = {const_cast<char*> ("Jean Bréfort"), NULL};
+	char * artists[] = {const_cast<char*> ("Nestor Diaz"), NULL};
 	char license[] = "This program is free software; you can redistribute it and/or\n" 
 		"modify it under the terms of the GNU General Public License as\n"
  		"published by the Free Software Foundation; either version 2 of the\n"
