@@ -4,7 +4,7 @@
  * GChemPaint library
  * arrow.cc 
  *
- * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -72,7 +72,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 		SetId (tmp);
 		xmlFree (tmp);
 	}
-	child = GetNodeByName (node, "start");
+	child = GetNodeByName (node, const_cast<char*> ("start"));
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
@@ -88,7 +88,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 	xmlFree (tmp);
 	if (result)
 		return false;
-	child = GetNodeByName (node, "end");
+	child = GetNodeByName (node, const_cast<char*> ("end"));
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
