@@ -4,9 +4,7 @@
  * GChemPaint library
  * atom.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -48,14 +46,16 @@
 #include "libgcpcanvas/gcp-canvas-bpath.h"
 #include "libgcpcanvas/gcp-canvas-rich-text.h"
 #include "libgcpcanvas/gcp-canvas-text.h"
-#include <math.h>
 #include <gcu/element.h>
+#include <cmath>
 #ifdef HAS_OPENBABEL_2
 #	include <openbabel/mol.h>
 #endif
 
 using namespace gcu;
 
+#define ATOM_EPSILON 0.1
+
 extern GtkTextTagTable* TextTagTable;
 
 gcpAtom::gcpAtom(): Atom()
@@ -204,18 +204,21 @@ bool gcpAtom::GetBestSide()
 	else return Element::BestSide(m_Z);
 }
 
-void gcpAtom::Update()
+void gcpAtom::Update ()
 {
-	if (m_ChargeAuto)
-	{
+	if (m_ChargeAuto) {
 		m_Charge = 0;
 		m_ChargeAuto = false;
 	}
+	if (m_ChargeAutoPos) {
+		NotifyPositionOccupation (m_ChargePos, false);
+		m_ChargePos = 0xff;
+	}
 	int nb, nexplp = 0, nexplu = 0; //nexplp is the number of explicit lone pairs
 	//nexplu is the number of explicit unpaired electrons
 	map<string, Object*>::iterator i;
 	gcpElectron* electron = (gcpElectron*) GetFirstChild (i);
-	while (electron){ 
+	while (electron) { 
 		if (electron->IsPair ())
 			nexplp++;
 		else
@@ -795,6 +798,9 @@ void gcpAtom::Update(GtkWidget* w)
 		if (item)
 			gtk_object_destroy (GTK_OBJECT (item));
 			g_object_set_data ((GObject*)group, "charge", NULL);
+			g_object_set_data ((GObject*)group, "figure", NULL);
+			g_object_set_data ((GObject*)group, "circle", NULL);
+			g_object_set_data ((GObject*)group, "sign", NULL);
 	}
 	map<string, Object*>::iterator i;
 	Object* electron = GetFirstChild (i);
@@ -836,14 +842,30 @@ void gcpAtom::UpdateAvailablePositions ()
 		while ((n != m_AngleList.end()) && (*n < angle)) n++;
 		m_AngleList.insert(n, angle);
 		i++;
-		if ((m_AvailPos & CHARGE_SW) && (angle >= 180.0) && (angle <= 270.0)) m_AvailPos -= CHARGE_SW;
-		if ((m_AvailPos & CHARGE_SE) && (((angle >= 270.0) && (angle <= 360.0)) || (fabs(angle) < 0.1))) m_AvailPos -= CHARGE_SE;
-		if ((m_AvailPos & CHARGE_S) && (angle >= 225.0) && (angle <= 315.0)) m_AvailPos -= CHARGE_S;
-		if ((m_AvailPos & CHARGE_NW) && (angle >= 90.0) && (angle <= 180.0)) m_AvailPos -= CHARGE_NW;
-		if ((m_AvailPos & CHARGE_NE) && (((angle >= 0.0) && (angle <= 90.0)) || (fabs(angle - 360.0) < 0.1))) m_AvailPos -= CHARGE_NE;
-		if ((m_AvailPos & CHARGE_N) && (angle >= 45.0) && (angle <= 135.0)) m_AvailPos -= CHARGE_N;
-		if ((m_AvailPos & CHARGE_W) && ((angle <= 225.0) && (angle >= 135.0))) m_AvailPos -= CHARGE_W;
-		if ((m_AvailPos & CHARGE_E) && ((angle >= 315.0) || (angle <= 45.0))) m_AvailPos -= CHARGE_E;
+		if ((m_AvailPos & CHARGE_SW) && (angle >= 180.0 - ATOM_EPSILON) &&
+			(angle <= 270.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_SW;
+		if ((m_AvailPos & CHARGE_SE) && (((angle >= 270.0 - ATOM_EPSILON) &&
+			(angle <= 360.0 + ATOM_EPSILON)) || (fabs(angle) < ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_SE;
+		if ((m_AvailPos & CHARGE_S) && (angle >= 225.0 - ATOM_EPSILON) &&
+			(angle <= 315.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_S;
+		if ((m_AvailPos & CHARGE_NW) && (angle >= 90.0 - ATOM_EPSILON) &&
+			(angle <= 180.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_NW;
+		if ((m_AvailPos & CHARGE_NE) && (((angle >= 0.0 - ATOM_EPSILON) &&
+			(angle <= 90.0 + ATOM_EPSILON)) || (fabs(angle - 360.0) < ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_NE;
+		if ((m_AvailPos & CHARGE_N) && (angle >= 45.0 - ATOM_EPSILON) &&
+			(angle <= 135.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_N;
+		if ((m_AvailPos & CHARGE_W) && ((angle <= 225.0 + ATOM_EPSILON) &&
+			(angle >= 135.0 - ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_W;
+		if ((m_AvailPos & CHARGE_E) && ((angle >= 315.0 - ATOM_EPSILON) ||
+			(angle <= 45.0 + ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_E;
 	}
 	m_AngleList.push_back ((angle = m_AngleList.front ()) + 360.0);
 	m_InterBonds.clear ();
@@ -1090,11 +1112,11 @@ void gcpAtom::SetSelected(GtkWidget* w, int state)
 	
 	switch (state)
 	{	
-		case SelStateUnselected: color = "white"; chargecolor = "black"; break;
+		case SelStateUnselected: color = const_cast<char*> ("white"); chargecolor = const_cast<char*> ("black"); break;
 		case SelStateSelected: chargecolor = color = SelectColor; break;
 		case SelStateUpdating: chargecolor = color = AddColor; break;
 		case SelStateErasing: chargecolor = color = DeleteColor; break;
-		default: color = "white"; chargecolor = "black"; break;
+		default: color = const_cast<char*> ("white"); chargecolor = const_cast<char*> ("black"); break;
 	}
 	g_object_set (G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")),
 				"fill_color", color, NULL);
@@ -1242,6 +1264,7 @@ void gcpAtom::BuildItems (gcpWidgetData* pData)
 			g_object_set_data (G_OBJECT (group), "symbol", NULL);
 		}
 		m_length = m_text_height = 0;
+		gnome_canvas_item_lower_to_bottom (GNOME_CANVAS_ITEM (group));
 	}
 	m_width /= pData->ZoomFactor;
 	m_height /= pData->ZoomFactor;
@@ -1367,31 +1390,31 @@ xmlNodePtr gcpAtom::Save (xmlDocPtr xml)
 		if (m_ChargePos) {
 			switch (m_ChargePos) {
 			case CHARGE_NE:
-				buf = "ne";
+				buf = const_cast<char*> ("ne");
 				break;
 			case CHARGE_NW:
-				buf = "nw";
+				buf = const_cast<char*> ("nw");
 				break;
 			case CHARGE_N:
-				buf = "n";
+				buf = const_cast<char*> ("n");
 				break;
 			case CHARGE_SE:
-				buf = "se";
+				buf = const_cast<char*> ("se");
 				break;
 			case CHARGE_SW:
-				buf = "sw";
+				buf = const_cast<char*> ("sw");
 				break;
 			case CHARGE_S:
-				buf = "s";
+				buf = const_cast<char*> ("s");
 				break;
 			case CHARGE_E:
-				buf = "e";
+				buf = const_cast<char*> ("e");
 				break;
 			case CHARGE_W:
-				buf = "w";
+				buf = const_cast<char*> ("w");
 				break;
 			default:
-				buf = "def"; // should not occur
+				buf = const_cast<char*> ("def"); // should not occur
 			}
 			xmlNewProp (node, (xmlChar*) "charge-position", (xmlChar*) buf);
 		} else {
@@ -1523,3 +1546,31 @@ void gcpAtom::SetCharge (int charge)
 	m_ChargeAuto = false;
 	Update ();
 }
+
+void gcpAtom::Transform2D (Matrix2D& m, double x, double y)
+{
+	Atom::Transform2D (m, x, y);
+	// Now transform electrons
+	map<string, Object*>::iterator i;
+	Object* electron = GetFirstChild (i);
+	while (electron) {
+		electron->Transform2D (m, x, y);
+		electron = GetNextChild (i);
+	}
+	if (GetCharge ()) {
+		m_ChargeAutoPos = false; // should be fixed before 0.6.4
+/*		if (m_ChargeAutoPos) {
+			if (m_ChargePos > 0)
+				NotifyPositionOccupation (m_ChargePos, false);
+			m_ChargePos = 0xff;
+			Update ();
+		} else {*/
+			double xc = cos (m_ChargeAngle), yc = - sin (m_ChargeAngle);
+			m.Transform (xc, yc);
+			m_ChargeAngle = atan2 (- yc, xc);
+			if (m_ChargeAngle < 0)
+				m_ChargeAngle += 2 * M_PI;
+			SetChargePosition (0, FALSE, m_ChargeAngle, m_ChargeDist);
+//		}
+	}
+}
