@@ -4,7 +4,7 @@
  * GChemPaint library
  * mesomery.cc 
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,12 +33,12 @@
 #include "mesomery-arrow.h"
 #include "mesomer.h"
 #include <glib/gi18n.h>
-#include <math.h>
+#include <cmath>
 #include <set>
 
 gcpMesomery::gcpMesomery (): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId (const_cast<char*> ("msy1"));
 }
 
 gcpMesomery::~gcpMesomery ()
@@ -764,7 +764,7 @@ bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 
 gcpMesomery::gcpMesomery (Object* parent, gcpMesomer *mesomer): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId (const_cast<char*> ("msy1"));
 	SetParent (parent);
 	AddChild (mesomer);
 	set<Object *> Objects;
