@@ -4,7 +4,7 @@
  * GChemPaint library
  * reactant.cc 
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,7 +34,7 @@ extern xmlDocPtr pXmlDoc;
 
 gcpReactant::gcpReactant (): Object (ReactantType)
 {
-	SetId ("r1");
+	SetId (const_cast<char*> ("r1"));
 	m_Stoich = 0;
 	Child = NULL;
 	Stoichiometry = NULL;
@@ -42,7 +42,7 @@ gcpReactant::gcpReactant (): Object (ReactantType)
 
 gcpReactant::gcpReactant (gcpReactionStep* step, Object *object)	throw (invalid_argument): Object (ReactantType)
 {
-	SetId ("r1");
+	SetId (const_cast<char*> ("r1"));
 	step->AddChild (this);
 	GetDocument ()->EmptyTranslationTable();
 	static const set<TypeId>& allowed_types = Object::GetRules ("reactant", RuleMayContain);
