@@ -249,13 +249,13 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 		g_value_init(&val, G_TYPE_STRING);
 		g_object_get_property((GObject*) tag, "name", &val);
 		const gchar* name = g_value_get_string(&val);
-		if (!strcmp(name, "bold")) tagname = "b";
-		else if  (!strcmp(name, "italic")) tagname = "i";
-		else if  (!strcmp(name, "underline")) tagname = "u";
-		else if  (!strcmp(name, "strikethrough")) tagname = "s";
-		else if  (!strcmp(name, "subscript")) tagname = "sub";
-		else if  (!strcmp(name, "superscript")) tagname = "sup";
-		else tagname = "font";
+		if (!strcmp(name, "bold")) tagname = const_cast<char*> ("b");
+		else if  (!strcmp(name, "italic")) tagname = const_cast<char*> ("i");
+		else if  (!strcmp(name, "underline")) tagname = const_cast<char*> ("u");
+		else if  (!strcmp(name, "strikethrough")) tagname = const_cast<char*> ("s");
+		else if  (!strcmp(name, "subscript")) tagname = const_cast<char*> ("sub");
+		else if  (!strcmp(name, "superscript")) tagname = const_cast<char*> ("sup");
+		else tagname = const_cast<char*> ("font");
 		OtherTagList = g_slist_append(OtherTagList, tag);
 		TagList = g_slist_remove(TagList, tag);
 		xmlNodePtr child = xmlNewDocNode(xml, NULL, (xmlChar*)tagname, NULL);
@@ -657,7 +657,7 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 	gchar* color;
 	switch (state) {	
 		case SelStateUnselected:
-			color = "white";
+			color = const_cast<char*> ("white");
 			break;
 		case SelStateSelected:
 			color = SelectColor;
@@ -669,7 +669,7 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 			color = DeleteColor;
 			break;
 		default:
-			color = "white";
+			color = const_cast<char*> ("white");
 			break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")), "fill_color", color, NULL);
