@@ -4,7 +4,7 @@
  * GChemPaint atoms plugin
  * chargetool.cc 
  *
- * Copyright (C) 2003-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2003-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,12 +28,12 @@
 #include "lib/document.h"
 #include "lib/application.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 gcpChargeTool::gcpChargeTool(gcpApplication *App, string Id): gcpTool(App, Id)
 {
-	if (Id == string("ChargePlus")) m_glyph = "\xE2\x8a\x95";
-	else if (Id == string("ChargeMinus")) m_glyph = "\xE2\x8a\x96";
+	if (Id == string("ChargePlus")) m_glyph = const_cast<char*> ("\xE2\x8a\x95");
+	else if (Id == string("ChargeMinus")) m_glyph = const_cast<char*> ("\xE2\x8a\x96");
 	else m_glyph = 0;
 }
 
