@@ -4,9 +4,7 @@
  * GChemPaint selection plugin
  * erasertool.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,12 +23,12 @@
  */
 
 #include "gchempaint-config.h"
-#include <math.h>
 #include "erasertool.h"
 #include "lib/settings.h"
 #include "lib/document.h"
 #include "lib/atom.h"
 #include "lib/bond.h"
+#include <cmath>
 
 gcpEraserTool::gcpEraserTool(gcpApplication* App): gcpTool(App, "Erase")
 {
